clear all

m=car_data2;
ci=load('ci_measdata');

V=[1:1:30];
V(1)=1e-6;
R=101;
[ay_gain, yaw_gain, beta_gain, eta, Vc]=car_steady_state(m,V);
ay=V.*V/R;
ds = ay./ay_gain;

plot( ci.ay_left/9.81,ci.ds_left/m.is,'s:',...
     -ci.ay_right/9.81,-ci.ds_right/m.is,'d:',...
      ay/9.81,ds/m.is,'-',... 
      [0 0.8],[m.l/R m.l/R],'--')
  
axis([0 0.8 0 0.12])
grid
xlabel('lateral acceleration a_y /g [-]')
ylabel('steer angle \delta [rad.]')
legend('left turn','right turn',['model (\eta=' num2str(eta,2) ' rad.)'],'l/R',2)
print -dpdf plot_ci_model_ay_fig221


figure
plot(ci.V_left,ci.r_left./ci.ds_left*m.is,'s:',...
     ci.V_right,ci.r_right./ci.ds_right*m.is,'d:',...
     V,yaw_gain*m.is,'-',...
     V,V/m.l,'-.')
axis([0 30 0 4])
grid
xlabel('forward velocity [m/s]')
ylabel('r/ \delta [1/s]')
legend('left turn','right turn',['model (\eta=' num2str(eta,2) ' rad.)'],'V/l',4)
print -dpdf plot_ci_model_yaw_fig222



beta_left_new =-(ci.vy_left +ci.r_left*(4.415-m.a))./ci.V_left;
beta_right_new=-(ci.vy_right+ci.r_right*(4.415-m.a))./ci.V_right;
b=m.l-m.a;
[x,idx_left]=sort(ci.ay_left);
[x,idx_right]=sort(ci.ay_right);
ay_meas=[0.5:0.1:7.4];
beta_left_i =interp1(ci.ay_left(idx_left),beta_left_new(idx_left),ay_meas);
beta_right_i=interp1(-ci.ay_right(idx_right),-beta_right_new(idx_right),ay_meas);

figure
plot( ci.ay_left,beta_left_new*180/pi,'s:',...
     -ci.ay_right,-beta_right_new*180/pi,'d:',...
      ay,ds.*beta_gain*180/pi,'-',...
      ay_meas,180/pi*(beta_left_i+beta_right_i)/2,'--',...
      [0 8],-[b/R b/R]*180/pi,'-.')

axis([0 8 -2 4])
grid
xlabel('lateral acceleration a_y [m/s2]')
ylabel('vehicle side slip angle \beta [deg.]')
legend('left turn','right turn',['model (\eta=' num2str(eta,2) ' rad.)'],'average left/right','-b/R',2)
print -dpdf plot_ci_model_beta_fig223

[alpha_1f,alpha_2f,mu_f]=inv_mf(m.mu1,m.cfa1,m.C1,m.E1);
[alpha_1r,alpha_2r,mu_r]=inv_mf(m.mu2,m.cfa2,m.C2,m.E2);

alpha_t=[0:0.1:15];
[FyFz_f]=mf(m.mu1,m.cfa1,m.C1,m.E1,alpha_t*pi/180);
[FyFz_r]=mf(m.mu2,m.cfa2,m.C2,m.E2,alpha_t*pi/180);

idx_f=find(FyFz_f < max(-ci.ay_right/m.g));
idx_r=find(FyFz_r < max(-ci.ay_right/m.g));

figure
plot(alpha_t(idx_f),FyFz_f(idx_f),'r-',...
     alpha_t(idx_r),FyFz_r(idx_r),'b--',...
     alpha_t,FyFz_f,'r:',...
     alpha_t,FyFz_r,'b:');
xlabel('side slip angle \alpha [deg.]') 
ylabel('Fy/Fz [-]')
legend('front tyre','rear tyre',4)
grid
print -dpdf plot_ci_nl_tyre_fig234 
 
nf=length(mu_f);
nr=length(mu_r);

if (nf>nr) 
  alpha_1f=alpha_1f(1:nr);
  alpha_2f=alpha_2f(1:nr);
  mu=mu_r;
else
  alpha_1r=alpha_1r(1:nf);
  alpha_2r=alpha_2r(1:nf);
  mu=mu_f;
end

nl_V=sqrt(mu*m.g*R);
nl_r=nl_V/R;
nl_delta=m.l/R+alpha_1f-alpha_1r;
nl_yaw_gain=nl_r./nl_delta;
nl_beta=m.a/m.l*alpha_1r + (m.l-m.a)/m.l*(alpha_1f-nl_delta);


figure
plot(-ci.ds_left/m.is+m.l/R,ci.ay_left/9.81,'s:',...
      ci.ds_right/m.is+m.l/R,-ci.ay_right/9.81,'d:',...
       alpha_1r-alpha_1f,mu,'-',...
       [0 -eta],[0 1],'--',...
       [m.l/R m.l/R],[0 0.9],'-.')
axis([-0.1 0.04 0 0.9 ])
grid
xlabel('\alpha2 - \alpha1 [rad]')
ylabel('ay/g  [-]')
legend('left turn','right turn','non-linear model','linear model','l/R (R=100 m)',3)
print -dpdf plot_ci_model_handling_diagram_fig235


figure
plot(ci.V_left,ci.r_left./ci.ds_left*m.is,'s:',...
     ci.V_right,ci.r_right./ci.ds_right*m.is,'d:',...
     nl_V,nl_yaw_gain,'-',...
     V,yaw_gain*m.is,'--',...
     V,V/m.l,'-.')
axis([0 30 0 4])
grid
xlabel('forward velocity [m/s]')
ylabel('r/ \delta [1/s]')
legend('left turn','right turn','non-linear model','linear model','V/l',4)
print -dpdf plot_ci_model_yaw_nl_fig237


figure
plot( ci.ay_left,beta_left_new*180/pi,'s:',...
     -ci.ay_right,-beta_right_new*180/pi,'d:',...
      mu*m.g,nl_beta*180/pi,'-',...
      ay,ds.*beta_gain*180/pi,'-.',...
      ay_meas,180/pi*(beta_left_i+beta_right_i)/2,'--',...
      [0 8],-[b/R b/R]*180/pi,'-.')

axis([0 8 -2 4])
grid
xlabel('lateral acceleration a_y [m/s2]')
ylabel('vehicle side slip angle \beta [deg.]')
legend('left turn','right turn','non-linear','linear model','average','-b/R',2)
print -dpdf plot_ci_model_beta_nl_fig236
